"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const getAttributeIdentifiers = options => {
  if (!options || typeof options.attributes === 'undefined') return ['data-test-id', 'data-testid'];

  if (Array.isArray(options.attributes)) {
    if (options.attributes.length === 0) {
      throw new Error('option attributes must be an array with at least one element');
    }

    if (options.attributes.length !== options.attributes.filter(attr => attr && typeof attr === 'string').length) {
      throw new Error('all items in the option attributes must be non empty strings');
    }

    return options.attributes;
  }

  if (!options.attributes || typeof options.attributes !== 'string') {
    throw new Error('option attributes must be a non empty string or an array with non empty strings');
  }

  return [options.attributes];
};

const RemoveDataTestIds = ({
  types: t
}) => {
  const visitor = {
    JSXOpeningElement: (path, state) => {
      if (path.node.hasStripped) {
        return;
      }

      const attributeIdentifiers = getAttributeIdentifiers(state.opts);

      const validTestIdAttributes = attr => {
        const isIdent = attributeIdentifiers.find(attribute => {
          return t.isJSXIdentifier(attr.name, {
            name: attribute
          });
        });
        return t.isJSXAttribute(attr) && isIdent;
      };

      const replaceClassNameValues = attr => {
        const matchingAttrs = currentAttr => {
          if (attr !== currentAttr) {
            return currentAttr;
          }
        };

        const isDefined = value => typeof value !== 'undefined';

        const attrs = path.node.attributes.map(matchingAttrs).filter(isDefined);
        const node = t.jSXOpeningElement(path.node.name, attrs, path.node.selfClosing);
        node.hasStripped = true;
        path.replaceWith(node);
      };

      path.node.attributes.filter(validTestIdAttributes).forEach(replaceClassNameValues);

      const isObjectDefined = value => Object.keys(value).length !== 0;

      const matchAndReplaceValues = currentAttr => {
        const _currentAttr$value = currentAttr.value,
              _currentAttr$value2 = _currentAttr$value === void 0 ? {} : _currentAttr$value,
              _currentAttr$value2$e = _currentAttr$value2.expression,
              _currentAttr$value2$e2 = _currentAttr$value2$e === void 0 ? {} : _currentAttr$value2$e,
              _currentAttr$value2$e3 = _currentAttr$value2$e2.properties,
              properties = _currentAttr$value2$e3 === void 0 ? [] : _currentAttr$value2$e3;

        const filteredProperties = properties.filter(property => attributeIdentifiers.includes(property.key.value));

        if (filteredProperties.length === 0) {
          return _objectSpread({}, currentAttr, {
            properties: filteredProperties
          });
        }

        return {};
      };

      const attrs = path.node.attributes.map(matchAndReplaceValues).filter(isObjectDefined);
      const node = t.jSXOpeningElement(path.node.name, attrs, path.node.selfClosing);
      node.hasStripped = true;
      path.replaceWith(node);
    }
  };
  return {
    visitor
  };
};

var _default = RemoveDataTestIds;
exports.default = _default;